% This code solve the steady state of the benchmark model of
% Chen and Song (2013), "Financial Friction on Capital Allocation, A Transmisison Mechanism of TFP Fluctuations"

clear all;

% parameter values in the full-blown model
theta=0.90;     % survival probability of lender's project
z_ss=1;         % project specific technology of type-u project
the_ss=1.34;    % project-specific technology of type-c project
alp=0.33;       % capital share in the production
bet_max=0.979;  % discount factor of type-u entrepreneurs
bet_min=0.745;  % discount factor of type-c entrepreneur
sig=1.00;       % inverse of the elasticity of intertemporal substitution in consumption
phi=1.927;      % leisure preference
nu1=0.40;       % leisure preference elasticity
eta=0.25;       % share of type-c project
p_h=0.95;       % persistence of news shocks
del=0.04;       % depreciation rate of capital stock
ps1=1.0;        % normalization
kapa=2.5;       % capital adjustment cost parameter
gg=0.0183;      % long-run growth rate of output per capita
nn=0.0148;      % long run growth rate of population
mu1=0.85;       % markup of final goods 
T=150;          % length of transitional dynamics


% Computing the steady state
r_ss=(1+gg)/bet_max-1;  %interest rate

save parameter r_ss bet_max bet_min del z_ss theta alp eta p_h r_ss T ps1 gg nn phi the_ss mu1 nu1 kapa

% solve for steady state capital of type-u project and aggregate output
options=optimset('Display','iter','LargeScale','off','NonlEqnAlgorithm','gn','TolX',1e-10,'TolFun',1e-10);
x0=[1.38,0.64];
x1=fsolve('fun_ss_benchmark',x0,options);
k_h_ss=x1(1);
y_ss=x1(2);

% solve for other variables at Steady State
n_h_ss=(k_h_ss^(1-alp*mu1)*(r_ss+del)/(y_ss^(1-mu1)*alp*mu1*z_ss))^(1/((1-alp)*mu1));                       % labor input in type-u project
w_ss=y_ss^(1-mu1)*(1-alp)*mu1*z_ss*k_h_ss^(alp*mu1)*n_h_ss^((1-alp)*mu1-1);                                 % wage rate
n_ss=(w_ss/phi)^(1/nu1);                                                                                    % aggregate labor
n_e_ss=(n_ss-(1-eta)*n_h_ss)/eta;                                                                           % labor input in type-c project
k_e_ss=(w_ss*n_e_ss^(1-(1-alp)*mu1)/((1-alp)*mu1*y_ss^(1-mu1)*the_ss))^(1/(alp*mu1));                       % capital in type-c project
prof_h_ss=y_ss^(1-mu1)*z_ss*(k_h_ss^alp*n_h_ss^(1-alp))^mu1-(r_ss+del)*k_h_ss-w_ss*n_h_ss;                  % profit in the type-u project
prof_e_ss=y_ss^(1-mu1)*the_ss*(k_e_ss^alp*n_e_ss^(1-alp))^mu1-(r_ss+del)*k_e_ss-w_ss*n_e_ss;                % profit in the type-c project
k_ss=(1-eta)*k_h_ss+eta*k_e_ss;                                                                             % aggregate capital stock
i_ss=(del+gg+nn)*k_ss;                                                                                      % new capital installed
k_l_ss=(mu1*y_ss^(1-mu1)*z_ss*((1-alp)/w_ss)^((1-alp)*mu1)*(alp/(r_ss+del))^(1-(1-alp)*mu1))^(1/(1-mu1));   % capital demand of lender
n_l_ss=(mu1*y_ss^(1-mu1)*z_ss*((1-alp)/w_ss)^(1-alp*mu1)*(alp/(r_ss+del))^(alp*mu1))^(1/(1-mu1));           % labor demand of lender
prof_l_ss=(1-mu1)*y_ss^(1-mu1)*z_ss*(k_l_ss^alp*n_l_ss^(1-alp))^mu1;                                        % profit of lender
v_ss=prof_l_ss/(1/(bet_max*theta*(1+gg)*(1+nn))-1);                                                         % discounted value of project to the lender
a_e_ss=(k_e_ss^alp-theta*v_ss)/(ps1*bet_max*(1+gg)*(1+nn));                                                 % asset demand of type-c entrepreneur
c_e_ss=prof_e_ss+(r_ss-gg-nn)*a_e_ss;                                                                       % consumption of type-c entrepreneur
lam_e_ss=1/c_e_ss;                                                                                          % shadow price of consumption of type-c entrepreneur
mu_ss=lam_e_ss*(alp*mu1*y_ss^(1-mu1)*the_ss*(k_e_ss^alp*n_e_ss^(1-alp))^mu1-(r_ss+del)*k_e_ss)/(alp*k_e_ss^alp); 
mu1_ss=lam_e_ss*(1-bet_min/bet_max)/(ps1*bet_max);                                                          % lagrange multiplier of financial constraint
a_h_ss=(k_h_ss^alp-theta*v_ss)/(ps1*bet_max*(1+gg)*(1+nn));                                                 % asset demand of type-u entrepreneur
c_h_ss=prof_h_ss+(r_ss-gg-nn)*a_h_ss;                                                                       % consumption of type-u entrepreneur
gam_ss=lam_e_ss-bet_min/(1+gg)*lam_e_ss*(1+r_ss)-mu_ss*ps1*bet_max;                                         % lagrange multiplier of nonnegative constraint of net worth of type-c entrepreneur
y_e_ss=the_ss*(k_e_ss^alp*n_e_ss^(1-alp))^mu1;                                                              % output per type-c entrepreneur
y_h_ss=z_ss*(k_h_ss^alp*n_h_ss^(1-alp))^mu1;                                                                % output per type-u entrepreneur
a_ss=eta*a_e_ss+(1-eta)*a_h_ss;                                                                             % total asset of entrepreneurs
a_w_ss=k_ss-a_ss;                                                                                           % asset demand of household 
c_w_ss=(r_ss-gg-nn)*a_w_ss+w_ss*n_ss;                                                                       % consumption of household
c_ss=eta*c_e_ss+(1-eta)*c_h_ss+c_w_ss;                                                                      % aggregate consumption
v_ss=prof_l_ss/(1-bet_max*theta*(1+gg)*(1+nn));                                                             % value of project to the lender
Ev_ss=(v_ss-prof_l_ss)/(bet_max*theta*(1+gg)*(1+nn));                                                       % expected future value of the project                                                                        
q_ss=1.0;                                                                                                   % capital price
tfp_ss=y_ss/(k_ss^alp*n_ss^(1-alp));                                                                        % aggregate TFP
tfp_ss1=(eta*the_ss*(k_e_ss/k_ss)^(alp*mu1)*(n_e_ss/n_ss)^((1-alp)*mu1)+(1-eta)*z_ss*(k_h_ss/k_ss)^(alp*mu1)*(n_h_ss/n_ss)^((1-alp)*mu1))^(1/mu1)
mpk_ss=(k_e_ss/k_h_ss)^(alp*mu1-1)*(n_e_ss/n_h_ss)^((1-alp)*mu1)*the_ss/z_ss                                % dispersion of MPK between the two type of project

% checking the resource constraint to be held 
resource=y_ss-(del+gg+nn)*k_ss-c_ss


% save the steady state values
save data_ss c_e_ss c_h_ss c_w_ss c_ss a_e_ss a_h_ss a_w_ss a_ss k_e_ss k_h_ss k_ss y_e_ss y_h_ss y_ss i_ss tfp_ss mpk_ss v_ss prof_e_ss prof_h_ss tfp_ss1 mu_ss prof_l_ss lam_e_ss n_h_ss n_e_ss n_ss w_ss gam_ss k_l_ss n_l_ss q_ss


